@@ -28,10 +28,6 @@ SITE_ID = 1
 SECRET_KEY = '_wri=r&d4&a4&#f+29+ni0@&lzjz!f7luk%)2m@%u74y$8g@-w'
 
 INSTALLED_APPS = (
-    'django.contrib.auth',
-    'django.contrib.contenttypes',
     'django.contrib.sessions',
-    'django.contrib.sites',
-    'django.contrib.messages',
     'sessions_test',
-)
+)
\ No newline at end of file
